@@ -215,15 +215,11 @@ double car_drive_to_target_simulation(double boost_accel, double car_to_target,
     double t = 0;
     double v = car_speed;
     double d = car_to_target;
-    _Bool b_a;
 
     while (d > 50)
     {
-        b_a = 0;
-
         if (b > boost_consumption * simulation_dt && v < max_speed - (boost_accel * simulation_dt))
         {
-            b_a = 1;
             v += boost_accel * simulation_dt;
             b -= boost_consumption * simulation_dt;
         }
